CodeNode class final

A <code> span/block with optional language hint.

Inheritance

Constructors

CodeNode(String text, {String? language})
const

Properties

children List<DocumentNode>
Child nodes (empty for leaves). No cycles.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
language String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited