DartBuilderContent class final

Surface B: a pure-Dart DocumentNode builder (e.g. BlogPostBuilder.new).

Inheritance

Constructors

DartBuilderContent(String builderId)
const

Properties

builderId String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited