DocumentRootNode class final

The document root: an optional <head> plus a body.

Inheritance

Constructors

DocumentRootNode({HeadNode? head, required List<DocumentNode> body, String? lang})
const

Properties

body List<DocumentNode>
final
children List<DocumentNode>
Child nodes (empty for leaves). No cycles.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
final
lang String?
Optional lang for the <html> element.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited