JsonLdNode class final

A <script type="application/ld+json"> structured-data block.

This is the only <script> the serializer emits; its content is JSON data (not executable code) and is escaped to prevent </script> breakout.

Inheritance

Constructors

JsonLdNode(Map<String, Object?> json)
const

Properties

children List<DocumentNode>
Child nodes (empty for leaves). No cycles.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
json Map<String, Object?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited