LinkNode class final

A <link rel href> (e.g. canonical, hreflang alternate).

Inheritance

Constructors

LinkNode({required String rel, required SafeUrl href, String? hreflang})
const

Properties

children List<DocumentNode>
Child nodes (empty for leaves). No cycles.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
href SafeUrl
final
hreflang String?
final
rel String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited