navigateToForExtraction method

  1. @override
Future<void> navigateToForExtraction(
  1. RouteInfo route
)
override

Drives the underlying router to route so a widget-based extractor can pump the tree for that location. Returns once navigation is dispatched.

Implementation

@override
Future<void> navigateToForExtraction(RouteInfo route) async {
  _current = route;
}