SeoMeta class

The full metadata model of a route.

Constructors

SeoMeta({required String title, String? description, SafeUrl? canonical, RobotsDirectives robots = const RobotsDirectives(), OpenGraph? openGraph, TwitterCard? twitter, String? lang, String charset = 'utf-8', String viewport = 'width=device-width, initial-scale=1', List<HreflangAlternate> hreflang = const [], List<({String content, String name})> extraMeta = const [], List<({SafeUrl href, String rel})> extraLinks = const []})
const

Properties

canonical → SafeUrl?
final
charset → String
final
description → String?
final
final
extraMeta → List<({String content, String name})>
final
hashCode → int
The hash code for this object.
no setterinherited
hreflang → List<HreflangAlternate>
final
lang → String?
final
openGraph → OpenGraph?
final
robots → RobotsDirectives
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final
twitter → TwitterCard?
final
viewport → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited