SitemapEntry class
A single sitemap URL entry.
Constructors
-
SitemapEntry({required SafeUrl loc, DateTime? lastmod, ChangeFreq? changefreq, double? priority, List<
({SafeUrl href, String hreflang})> alternates = const []}) -
const
Properties
-
alternates
→ List<
({SafeUrl href, String hreflang})> -
final
- changefreq → ChangeFreq?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastmod → DateTime?
-
final
- loc → SafeUrl
-
final
- priority → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited