WidgetContent class final
Surface A: content extracted from route widgets at build time (SSG).
- Inheritance
-
- Object
- ContentSource
- WidgetContent
Constructors
- WidgetContent([String? pageBuilderId])
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pageBuilderId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited