HtmxIslandNode class final
An HTMX island (level 1).
- Inheritance
-
- Object
- DocumentNode
- HtmxIslandNode
Constructors
-
HtmxIslandNode({required String id, required String endpoint, String trigger = 'load', String? target, String swap = 'innerHTML', List<
DocumentNode> fallback = const []}) -
const
Properties
-
children
→ List<
DocumentNode> -
Child nodes (empty for leaves). No cycles.
no setteroverride
- endpoint → String
-
final
-
fallback
→ List<
DocumentNode> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- swap → String
-
final
- target → String?
-
final
- trigger → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited