IslandPlaceholderNode class final
A Flutter island (level 2).
- Inheritance
-
- Object
- DocumentNode
- IslandPlaceholderNode
Constructors
-
IslandPlaceholderNode({required String id, HydrationDirective directive = HydrationDirective.onIdle, IslandRenderMode renderMode = IslandRenderMode.ssr, IslandStyleMode styleMode = IslandStyleMode.shadow, IslandSize? size, Map<
String, Object?> state = const {}, String? mediaQuery, List<DocumentNode> fallback = const []}) -
const
Properties
-
children
→ List<
DocumentNode> -
Child nodes (empty for leaves). No cycles.
no setteroverride
- directive → HydrationDirective
-
final
-
fallback
→ List<
DocumentNode> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- mediaQuery → String?
-
final
- renderMode → IslandRenderMode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → IslandSize?
-
final
-
state
→ Map<
String, Object?> -
final
- styleMode → IslandStyleMode
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited