Serialises island props across the server → HTML → client boundary.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
byteSize(
IslandState state) → int - Byte size of the JSON payload (before HTML-escaping).
-
decode(
String attributeValue) → IslandState -
Reverses encode: HTML-unescape then
jsonDecode. -
encode(
IslandState state) → String -
jsonEncode+ HTML-attribute escape. Throws ArgumentError on a non-JSON-safe value (e.g.DateTime,Uri, functions, etc).