MetaNode class final
A <meta> tag (name/property/content/charset).
- Inheritance
-
- Object
- DocumentNode
- MetaNode
Properties
- charset → String?
-
final
-
children
→ List<
DocumentNode> -
Child nodes (empty for leaves). No cycles.
no setteroverride
- content → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
final
- property → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited