Navigator2Adapter class
Fallback for bare Navigator 2.0 applications.
- Implemented types
Constructors
Properties
- current → RouteInfo?
-
The route most recently passed to navigateToForExtraction, or
nullbefore any navigation. Read by widget-based extractors to know which location the tree is currently pumped for.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
routes
→ List<
RouteInfo> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
Drives the underlying router to
routeso a widget-based extractor can pump the tree for that location. Returns once navigation is dispatched.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited